@@ -1,7 +1,7 @@
 package Perinci::CmdLine::Base;
 
-our $DATE = '2016-10-27'; # DATE
-our $VERSION = '1.63'; # VERSION
+our $DATE = '2016-12-02'; # DATE
+our $VERSION = '1.64'; # VERSION
 
 use 5.010001;
 use strict;
@@ -742,7 +742,7 @@ sub _parse_argv1 {
         require Getopt::Long;
         my $old_go_conf = Getopt::Long::Configure(
             'pass_through', 'no_ignore_case', 'bundling', 'no_auto_abbrev',
-            'no_getopt_compat');
+            'no_getopt_compat', 'gnu_compat');
         my $co = $self->common_opts // {};
         for my $k (keys %$co) {
             push @go_spec, $co->{$k}{getopt} => sub {
@@ -1450,7 +1450,7 @@ Perinci::CmdLine::Base - Base class for Perinci::CmdLine{::Classic,::Lite}
 
 =head1 VERSION
 
-This document describes version 1.63 of Perinci::CmdLine::Base (from Perl distribution Perinci-CmdLine-Lite), released on 2016-10-27.
+This document describes version 1.64 of Perinci::CmdLine::Base (from Perl distribution Perinci-CmdLine-Lite), released on 2016-12-02.
 
 =head1 DESCRIPTION
 
